package	jp.co.sds_corp.util.daemon.core;

import jp.co.sds_corp.util.config.IConfiguration;
import jp.co.sds_corp.util.log.CmnLogger;

/**
* 単純にサービスを一度だけ起動するデーモンクラス。
* DaemonManagerの起動時に一度だけサービスを起動します。
* 現実的には、テスト用にしか使えないでしょう。
<P>
XMLは以下の形式です。
<PRE>
&lt;Daemon name="DAEMON" class="jp.co.sds_corp.util.daemon.core.Daemon"&gt;
	&lt;Service name="service" class="daemon.ServiceTest"&gt;
		...
	&lt;/Service&gt;
&lt;/Daemon&gt;
</PRE>
*/
public class SimpleDaemon extends AbstractDaemon implements SimpleDaemonMBean
{
	static CmnLogger logger = CmnLogger.getInstance();

	/**
	* デーモンを初期化します。
	*/
	public void init( IConfiguration config ) throws Exception {
		super.init( config );
	}

	/**
	* デーモンを開始します。
	*/
	public void start() {
		if ( getStatus() == Status.ERROR ) {
			return;
		}
		setStatus( Status.RUN );
		if ( isDebug()) {
			logger.debug( this, "start service:" + getService() );
		}
		try {
			getService().start();
		} catch ( Throwable t ) {
			logger.error( this, "Service error", t );
			setStatus( Status.DEAD, t.getMessage() );
		}
		if ( isDebug()) {
			logger.debug( this, "end of service:" + getService() );
		}
		setStatus( Status.ALIVE );
	}

	/**
	* デーモンに割り込みます。
	*/
	public void terminate() {
		getService().stop();
		setStatus( Status.DEAD, "Terminated." );
	}

	/**
	* 全てのThreadの終了を待ちます。
	*/
	public void joinAll() {
	}

	/**
	* 設定されている内容をXML形式で出力します。
	* @param	config	設定情報
	*/
	public void saveConfig( IConfiguration config ) {
		super.saveConfig( config );
	}

}

